'use strict';

app.controller('LibraryOnlineCtrl', ['$scope', '$timeout', 'ImportExportService', 'FormService', 'FormDataService', 'UrlService', 'TranslateService', 'RestService', 'AlertService', 'ServiioLinkService', 'LibraryService', 'formData', 'onlineContentQualities', 'onlineRepositoryTypes', 'accessGroups',
    function ($scope, $timeout, ImportExportService, FormService, FormDataService, UrlService, TranslateService, RestService, AlertService, ServiioLinkService, LibraryService, formData, onlineContentQualities, onlineRepositoryTypes, accessGroups) {
	
    $scope.formData = formData;
    $scope.onlineContentQualities = onlineContentQualities;
    $scope.onlineRepositoryTypes = onlineRepositoryTypes;
    $scope.accessGroups = accessGroups;

    $scope.onlineItemsNumbers = [
    	{key: TranslateService.getMessage('tab_folders_online_max_number_of_feed_items_unlimited'), value: -1},
    	{key: '10', value: 10},
    	{key: '20', value: 20},
    	{key: '30', value: 30},
    	{key: '40', value: 40},
    	{key: '50', value: 50}
    ];

    $scope.addResourceOpen = false;

    var cleanAddForm = {
        repositoryType: 'FEED',
        fileType: 'VIDEO',
        contentUrl: '',
        enabled: true,
        accessGroupIds: [1]
    };

    var originalOnlineRepositories = angular.copy($scope.formData.onlineRepositories);
   

    function resetAddForm() { 
        $scope.editingOnlineResourceIndex = null;
        $scope.newOnlineSource = angular.copy(cleanAddForm);
        $scope.$broadcast("resettableFormReset"); // mark the inner form as pristine
    }

    function closeAddResourceForm() {
        $scope.addResourceOpen = false;
    }

    $scope.newOnlineSource = angular.copy(cleanAddForm);
    $scope.editingOnlineResourceIndex = null;

    $scope.$on("formStateReset", function (event, modified) {
        $scope.formData['onlineRepositories'] = angular.copy(originalOnlineRepositories);     
        LibraryService.markAsPristine($scope, null);
        resetAddForm();          
    });

    $scope.sortableOptions = {
        containment: '#foldersTableContainer',
        containerPositioning: 'relative',
        orderChanged : function(obj) {
            var form = angular.element("form").scope().Form;
            LibraryService.markAsModified($scope, form);
        }
    };


	$scope.submit = function (form) {
        FormService.submitForm('repository', $scope.formData, form, $scope);

        originalOnlineRepositories = angular.copy($scope.formData.onlineRepositories);

        LibraryService.markAsPristine($scope, form);
    };

    $scope.onlineRepoDisplayName = function(repository) {
    	return 'repositoryName' in repository ? repository.repositoryName : repository.contentUrl;
    }

    $scope.checkStreamUrl = function(fileType, streamUrl) {
        if(streamUrl == '') {
            AlertService.error(TranslateService.getMessage('error_mandatory_fields_empty'));
        } else {
            $scope.checkUrlStatusInProgress = true;
            var params = [fileType, streamUrl];
            RestService.invokeAction('checkStreamUrl', params, false, function(response) {   
                $scope.checkUrlStatusInProgress = false;
                var errorCode = response.data.errorCode;
                if(errorCode == 0) {
                    AlertService.success(TranslateService.getMessage('tab_folders_online_stream_url_valid'));
                } else {
                    AlertService.warning(TranslateService.getMessage('tab_folders_online_stream_url_invalid'));    
                }
            }, function(response) {            
                $scope.checkUrlStatusInProgress = false;
                RestService.processError(response);
            })
        }
    }

    $scope.openAddResourceForm = function() {
        $scope.openAddResourceFormWithModel(cleanAddForm);
    }


    $scope.openAddResourceFormWithModel = function(model) {
        $scope.newOnlineSource = LibraryService.prepareAccessGroupIds(angular.copy(model));
        $scope.addResourceOpen = true;
    }

    $scope.openEditResourceForm = function(index) {
        $scope.newOnlineSource = LibraryService.prepareAccessGroupIds(angular.copy($scope.formData.onlineRepositories[index]));
        $scope.addResourceOpen = true;
        $scope.editingOnlineResourceIndex = index;
    }

    $scope.addOnlineSource = function(form, index) {
        var valid = FormService.validateForm(form);
        if(valid) {
            var newSource = LibraryService.normalizeAccessGroupIds(angular.copy($scope.newOnlineSource));
            if(index != null) {
                // edit
                $scope.formData.onlineRepositories[index] = newSource;
            } else {
                // new
                $scope.formData.onlineRepositories.push(newSource);
            }

            LibraryService.markAsModified($scope, form.$$parentForm);
            closeAddResourceForm();
            resetAddForm();
        }     
    }

    $scope.cancelAddOnlineSource = function() {
        closeAddResourceForm();
        resetAddForm();
    }

    $scope.openServiioLinkDialog = function() {
        AlertService.prompt(TranslateService.getMessage("tab_folders_online_add_serviiolink"), TranslateService.getMessage("tab_folders_online_enter_serviiolink"), function(swal, input) {
            if(input === false) {
                // cancel
            } else if (input === "") {     
                swal.showInputError(TranslateService.getMessage("error_mandatory_fields_empty"));
            } else {
                var serviioLinkObj = ServiioLinkService.parse(input);
                if(serviioLinkObj == null) {
                    swal.showInputError(TranslateService.getMessage("error_serviio_link_invalid"));
                } else {
                    var prefilledForm = {
                        fileType: serviioLinkObj.fileType.toUpperCase(),
                        repositoryType: repoTypeFromServiioLink(serviioLinkObj.repoType),
                        contentUrl: serviioLinkObj.query['url'],
                        repositoryName: serviioLinkObj.query['name'],
                        thumbnailUrl: serviioLinkObj.query['thUrl'],
                        enabled: true,
                        accessGroupIds: [1]
                    };

                    swal.close();   
                    $scope.openAddResourceFormWithModel(prefilledForm);
                }                
            }
        });
    }

    $scope.removeOnlineResource = function(index, form) {
        var repos = $scope.formData.onlineRepositories;
        repos.splice(index, 1);
        LibraryService.markAsModified($scope, form);
    }


    $scope.generateServiioLink = function(index) {
        var repo = $scope.formData.onlineRepositories[index];
        var serviioLinkObj = {
            fileType: repo.fileType.toLowerCase(),
            repoType: repoTypeToServiioLink(repo.repositoryType),
            query: {
                url: repo.contentUrl,
                thUrl: repo.thumbnailUrl,
                name: repo.repositoryName
            }
        };
        var serviioLink = ServiioLinkService.generate(serviioLinkObj);
        AlertService.infoWithField(TranslateService.getMessage("tab_folders_online_generated_serviiolink"), null, serviioLink);
    }

    $scope.enableOrDisableOnlineResource = function(index, enabled, form) {
        $scope.formData.onlineRepositories[index].enabled = enabled;
        LibraryService.markAsModified($scope, form);
    }

    $scope.forceRefreshResource = function(index) {
        var repo = $scope.formData.onlineRepositories[index];
        if(repo.id) {
            var params = [repo.id];
            RestService.invokeAction('forceOnlineResourceRefresh', params, true);
        }
    }

    $scope.moveResourceUp = function(index, form) {
        if(index > 0) {
            var list = $scope.formData.onlineRepositories;
            list.splice(index - 1, 0, list.splice(index, 1)[0]);
            LibraryService.markAsModified($scope, form);
        }
    }

    $scope.moveResourceDown = function(index, form) {
        var list = $scope.formData.onlineRepositories;
        if(index < list.length) {            
            list.splice(index + 1, 0, list.splice(index, 1)[0]);
            LibraryService.markAsModified($scope, form);
        }
    }

    $scope.exportOnlineResources = function() {
        ImportExportService.export();
    }

    $scope.selectImportOnlineResources = function() {
         $timeout(function() {
            angular.element('#import').trigger('click');
        }, 100);
    }

    $scope.importOnlineResources = function(element) {
        var file = element.files[0];
        if (file) {
            var reader = new FileReader();
            reader.readAsText(file);
            reader.onload = function(e) {
                var backupData = e.target.result;
                ImportExportService.import(backupData, function(response) {
                    AlertService.success(TranslateService.getMessage('tab_folders_online_import_successful'), null, function() {
                        // reload imported repos

                        FormDataService.loadFormData('repository').then(function(json) {
                            UrlService.reloadPage($scope);
                        });

                    });                    
                });
            }
        }
    }

    $scope.isAccessGroupEnabled = function(groupId) {
        return LibraryService.isAccessGroupEnabled(groupId);
    } 

    function repoTypeFromServiioLink(serviioLinkRepoType) {
        if(serviioLinkRepoType == 'feed') {
            return 'FEED';
        } else if(serviioLinkRepoType == 'web') {
            return 'WEB_RESOURCE';
        } else {
            return 'LIVE_STREAM';
        }
    }

     function repoTypeToServiioLink(repoType) {
        if(repoType == 'FEED') {
            return 'feed';
        } else if(repoType == 'WEB_RESOURCE') {
            return 'web';
        } else {
            return 'live';
        }
    }

}]);
