'use strict';

app.controller('StatusCtrl', ['$scope', 'FormService', 'LibraryService', 'TranslateService', 'RestService', 'FormDataService', 'formData', 'accessGroups', 'profiles', 'networkInterfaces',
	function ($scope, FormService, LibraryService, TranslateService, RestService, FormDataService, formData, accessGroups, profiles, networkInterfaces) {
	
	$scope.formData = buildFormData(formData);
    $scope.accessGroups = fixAccessGroups(accessGroups);
    $scope.profiles = profiles;
    $scope.networkInterfaces = buildNetworkInterfaces(networkInterfaces);

    $scope.serverStatus = $scope.formData['serverStatus'];

    $scope.editRendererOpen = false;
    $scope.editingRendererIndex = null;
    $scope.editedRenderer = null;

    var originalRenderers = angular.copy($scope.formData.renderers);

    function resetEditForm() { 
        $scope.editingRendererIndex = null;
        $scope.$broadcast("resettableFormReset"); // mark the inner form as pristine
    }

    function closeEditForm() {
        $scope.editRendererOpen = false;
    }

    function fixAccessGroups(accessGroups) {
        for(var i = 0; i < accessGroups.length; i++) {
            accessGroups[i].name = parseInt(accessGroups[i].name);    
        }
        return accessGroups;
    }

    function buildFormData(formData) {
        if(! ('boundNICName' in formData)) {
            formData['boundNICName'] = 0;
        }
        return formData;
    }

     function buildNetworkInterfaces(networkInterfaces) {
        var nics = [];
        nics.push({name: 0, value: TranslateService.getMessage('tab_status_bound_ip_address_automatically_detected')});
        for(var i = 0; i < networkInterfaces.length; i++) {
            nics.push( networkInterfaces[i] );
        }
        return nics;
    }

    function presaveFormData(formData) {
        var formCopy = angular.copy(formData);
        if(formCopy.boundNICName == 0) {
            delete formCopy['boundNICName'];
        }
        return formCopy;
    }

    $scope.$on("formStateReset", function (event, modified) {
        $scope.formData['renderers'] = angular.copy(originalRenderers);     
        LibraryService.markAsPristine($scope, null);
        resetEditForm();          
    });

    $scope.submit = function (form) {
        FormService.submitForm('status', presaveFormData($scope.formData), form, $scope);

        originalRenderers = angular.copy($scope.formData.renderers);

        LibraryService.markAsPristine($scope, form);
    };

    $scope.reloadRenderers = function() {
        FormDataService.loadFormData('status').then(function(json) {
            $scope.formData['renderers'] = json.renderers;
            originalRenderers = angular.copy($scope.formData.renderers);
        });
    }

    $scope.profileName = function(profileId) {
        for(var i = 0; i < $scope.profiles.length; i++) {
            var profile = $scope.profiles[i];
            if(profile.name == profileId) {
                return profile.value;
            }
        }
        return profileId;
    }

    $scope.enableOrDisableRenderer = function(index, enabled, form) {
        $scope.formData.renderers[index].enabled = enabled;
        LibraryService.markAsModified($scope, form);
    }


    $scope.removeRenderer = function(index, form) {
        var renderers = $scope.formData.renderers;
        renderers.splice(index, 1);
        LibraryService.markAsModified($scope, form);
    }

    $scope.openEditRendererForm = function(index) {
        $scope.editedRenderer = angular.copy($scope.formData.renderers[index]);
        $scope.editRendererOpen = true;
        $scope.editingRendererIndex = index;
    }

    $scope.updateRenderer = function(form, index) {
        var valid = FormService.validateForm(form);
        if(valid) {
            var newSource = angular.copy($scope.editedRenderer);
            $scope.formData.renderers[index] = newSource;
            
            LibraryService.markAsModified($scope, form.$$parentForm);
            closeEditForm();
            resetEditForm();
        }     
    }

    $scope.cancelUpdateRenderer = function() {
        closeEditForm();
        resetEditForm();
    }

    $scope.startStopServer = function() {
        $scope.serverStartStopInProcess = true;
        if($scope.serverStatus == 'STARTED') {
            RestService.invokeAction('stopServer', null, true, function(response) {
                $scope.serverStatus = 'STOPPED';
                $scope.serverStartStopInProcess = false;
            }, function(response) {
                $scope.serverStartStopInProcess = false;
            });
        } else {
            RestService.invokeAction('startServer', null, true, function(response) {
                $scope.serverStatus = 'STARTED';
                $scope.serverStartStopInProcess = false;
            }, function(response) {
                $scope.serverStartStopInProcess = false;
            });
        }
    }


}]);
