'use strict';

app.controller('WelcomeCtrl', ['$scope', '$rootScope', '$localStorage', '$modal', 'TranslateService',
    function ($scope, $rootScope, $localStorage, $modal, TranslateService) {

    $scope.totalAudioFiles = 0;
    $scope.totalImageFiles = 0;
    $scope.totalVideoFiles = 0;	

    $rootScope.$on("fileTotalsUpdated", function (event, totalAudio, totalVideo, totalImage) {
        $scope.totalAudioFiles = totalAudio;
        $scope.totalVideoFiles = totalVideo;
        $scope.totalImageFiles = totalImage;
    });

    $scope.isUpdateAvailable = function() {
    	return $localStorage.showNewVersionNotification && $rootScope.applicationData.updateVersionAvailable ? true : false;
    }

    $scope.updateVersion = function() {
    	return '{version: "' + $rootScope.applicationData.updateVersionAvailable + '"}';
    }

    $scope.currentVersion = function() {
		var version = $rootScope.applicationData.version;
		return 'v ' + version;
    }

    $scope.currentEdition = function() {
    	var edition = $rootScope.applicationData.edition;
    	if(edition == 'FREE') {
    		return '';
    	} else {
    		return edition + ' ';
    	}
    }

    $scope.hasLicenseInfo = function() {
    	return $rootScope.applicationData.license ? true : false;
    }

    $scope.licenseInfo = function() {
    	var license = $rootScope.applicationData.license;    	
    	var licenseInfo = "";

    	if(license) {
	    	if(license.name) {    		
	    		licenseInfo = licenseInfo + TranslateService.getMessage('tab_about_licensed_to', {name: license.name, email: license.email}) + ' ';    		
	    	}

	    	if(license.type != 'NORMAL') {
	    		licenseInfo = licenseInfo +	TranslateService.getMessage('tab_about_license_type_' + license.type) + ' ';
	    		if(license.expiresInMinutes) {
					licenseInfo = licenseInfo + TranslateService.getMessage('tab_about_license_expires_in', {days: getDaysForMinutes(license.expiresInMinutes)});
	    		}
	    	}
		}
    	return licenseInfo;
    }

    $scope.showUploadLicenseButton = function() {
    	var license = $rootScope.applicationData.license;
    	if(license && (license.type == 'NORMAL' || license.type == 'UNLIMITED' )) {
    		return false;
    	} else {
    		return true;
    	}
    }


    $scope.openUploadLicenseModal = function() {
        $modal.open({
            templateUrl: 'uploadLicenseModal.html',
            controller: 'LicenseUploadCtrl'
        });
    }

    function getDaysForMinutes(minutes) {
    	return Math.floor(minutes/1440);
    }


}]);


app.controller('LicenseUploadCtrl', ['$scope', '$rootScope', '$modalInstance', '$timeout', 'LicenseUploadService', 'FormDataService', 'AlertService', 'TranslateService',
    function ($scope, $rootScope, $modalInstance, $timeout, LicenseUploadService, FormDataService, AlertService, TranslateService) {   

    $scope.licenseFileName = '';
    $scope.licenseFile = null;

    $scope.selectLicenseToUpload = function() {
         $timeout(function() {
            angular.element('#uploadLicense').trigger('click');
        }, 100);
    }

    $scope.confirmLicenseFileSelection = function(element) {
        $scope.licenseFileName = element.files[0].name;
        $scope.licenseFile = element.files[0];
    }

    $scope.save = function() {
        if ($scope.licenseFile) {
            var reader = new FileReader();
            reader.readAsText($scope.licenseFile);
            reader.onload = function(e) {
                var licenseBytes = e.target.result;
                LicenseUploadService.upload(licenseBytes, function(response) {
                    $modalInstance.close();
                    AlertService.success(TranslateService.getMessage('tab_about_upload_license_success'), null,  function() {
                        // reload the license info
                        FormDataService.loadFormData('application').then(function(responseData) {
                            $rootScope.applicationData = responseData;
                        });       
                    });
                });
            }
        }
    }

    $scope.cancel = function () {
        $modalInstance.dismiss();
    };
}]);